==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/TemplateHeaderCellUpdatingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TemplateHeaderCellUpdatingEventArgsDescription } from "./TemplateHeaderCellUpdatingEventArgsDescription";
/**
 * @hidden
 */
export let TemplateHeaderCellUpdatingEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class TemplateHeaderCellUpdatingEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (TemplateHeaderCellUpdatingEventArgsDescriptionMetadata.a == null) {
                TemplateHeaderCellUpdatingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                TemplateHeaderCellUpdatingEventArgsDescriptionMetadata.c(TemplateHeaderCellUpdatingEventArgsDescriptionMetadata.a);
            }
            if (a.j(TemplateHeaderCellUpdatingEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(TemplateHeaderCellUpdatingEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            TemplateHeaderCellUpdatingEventArgsDescriptionMetadata.b(a);
            a.aa("TemplateHeaderCellUpdatingEventArgs", () => new TemplateHeaderCellUpdatingEventArgsDescription());
            a.z("TemplateHeaderCellUpdatingEventArgs", TemplateHeaderCellUpdatingEventArgsDescriptionMetadata.a);
        }
    }
    TemplateHeaderCellUpdatingEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(TemplateHeaderCellUpdatingEventArgsDescriptionMetadata, 'TemplateHeaderCellUpdatingEventArgsDescriptionMetadata');
    TemplateHeaderCellUpdatingEventArgsDescriptionMetadata.a = null;
    return TemplateHeaderCellUpdatingEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/TemplateHeaderCellUpdatingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TemplateHeaderCellUpdatingEventArgsDescription } from "./TemplateHeaderCellUpdatingEventArgsDescription";
/**
 * @hidden
 */
export let TemplateHeaderCellUpdatingEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class TemplateHeaderCellUpdatingEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (TemplateHeaderCellUpdatingEventArgsDescriptionMetadata.a == null) {
                TemplateHeaderCellUpdatingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                TemplateHeaderCellUpdatingEventArgsDescriptionMetadata.c(TemplateHeaderCellUpdatingEventArgsDescriptionMetadata.a);
            }
            if (a.k(TemplateHeaderCellUpdatingEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(TemplateHeaderCellUpdatingEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            TemplateHeaderCellUpdatingEventArgsDescriptionMetadata.b(a);
            a.ac("TemplateHeaderCellUpdatingEventArgs", () => new TemplateHeaderCellUpdatingEventArgsDescription());
            a.ab("TemplateHeaderCellUpdatingEventArgs", TemplateHeaderCellUpdatingEventArgsDescriptionMetadata.a);
        }
    }
    TemplateHeaderCellUpdatingEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(TemplateHeaderCellUpdatingEventArgsDescriptionMetadata, 'TemplateHeaderCellUpdatingEventArgsDescriptionMetadata');
    TemplateHeaderCellUpdatingEventArgsDescriptionMetadata.a = null;
    return TemplateHeaderCellUpdatingEventArgsDescriptionMetadata;
})();
